==> qtjambi-network-debuginfo-macos-5.15.17.jar: sources/QtJambiNetwork/QNetworkAccessManager_shell.h <==
#ifndef QNETWORKACCESSMANAGER_SHELL_H
#define QNETWORKACCESSMANAGER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qabstractnetworkcache.h>
#include <QtNetwork/qauthenticator.h>
#include <QtNetwork/qhstspolicy.h>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttpmultipart.h>
#endif //QT_CONFIG(http)
#include <QtNetwork/qnetworkconfiguration.h>
#include <QtNetwork/qnetworkcookiejar.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslerror.h>
#if QT_CONFIG(ssl)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif //QT_CONFIG(ssl)
#include <QtJambi/RegistryAPI>


class QNetworkAccessManager_shell : public QNetworkAccessManager, public QtJambiShellInterface
{
public:
    QNetworkAccessManager_shell(QObject* parent0 = nullptr);
    ~QNetworkAccessManager_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QNetworkReply* createRequest(QNetworkAccessManager::Operation op0, const QNetworkRequest& request1, QIODevice* outgoingData2) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNetworkAccessManager_access : public QNetworkAccessManager
{
    jobject __qt_supportedSchemesImplementation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createRequest_QNetworkAccessManager_Operation_cref_QNetworkRequest_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint op0, QtJambiNativeID request1, QtJambiNativeID outgoingData2);
};

#endif // QNETWORKACCESSMANAGER_SHELL_H

==> qtjambi-network-debuginfo-macos-6.5.3.jar: sources/QtJambiNetwork/QNetworkAccessManager_shell.h <==
#ifndef QNETWORKACCESSMANAGER_SHELL_H
#define QNETWORKACCESSMANAGER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtNetwork/qabstractnetworkcache.h>
#include <QtNetwork/qauthenticator.h>
#include <QtNetwork/qhstspolicy.h>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttpmultipart.h>
#endif //QT_CONFIG(http)
#include <QtNetwork/qnetworkcookiejar.h>
#include <QtNetwork/qnetworkproxy.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslerror.h>
#if QT_CONFIG(ssl)
#include <QtNetwork/qsslpresharedkeyauthenticator.h>
#endif //QT_CONFIG(ssl)
#include <QtJambi/RegistryAPI>


class QNetworkAccessManager_shell : public QNetworkAccessManager, public QtJambiShellInterface
{
public:
    QNetworkAccessManager_shell(QObject* parent0 = nullptr);
    ~QNetworkAccessManager_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QNetworkReply* createRequest(QNetworkAccessManager::Operation op0, const QNetworkRequest& request1, QIODevice* outgoingData2) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QStringList supportedSchemes() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QNetworkAccessManager_access : public QNetworkAccessManager
{
    jobject __qt_supportedSchemesImplementation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_createRequest_QNetworkAccessManager_Operation_cref_QNetworkRequest_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint op0, QtJambiNativeID request1, QtJambiNativeID outgoingData2);
    jobject __qt_supportedSchemes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QNETWORKACCESSMANAGER_SHELL_H
